/*
 *	fhist - file history and comparison tools
 *	Copyright (C) 2000, 2002 Peter Miller;
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 * MANIFEST: interface definition for common/fcheck.c
 */

#ifndef COMMON_FCHECK_H
#define COMMON_FCHECK_H

#include <ac/stdio.h>

#include <main.h>

FILE *fopen_and_check(const char *, const char *);
void fflush_and_check(FILE *, const char *);
void fclose_and_check(FILE *, const char *);
void warning_last_line_unterminated(const char *);

struct sub_context_ty;
void fatal_with_filename(const char *, struct sub_context_ty *, const char *);

#endif /* COMMON_FCHECK_H */
